@@ -1,8 +1,6 @@
 package Geo::JSON::Base;
 
-our $VERSION = '0.006'; # VERSION
-
-# ABSTRACT: Base class for Geo::JSON objects
+our $VERSION = '0.007';
 
 use Moo;
 with 'Geo::JSON::Role::ToJson';
@@ -26,7 +24,6 @@ has crs => ( is => 'ro', isa => Maybe [CRS], coerce => CRS->coercion );
 
 has bbox => ( is => 'rw', isa => Maybe [ ArrayRef [Num] ] );
 
-
 # used by JSON 'convert_blessed'
 sub TO_JSON {
     my $self = $_[0];
@@ -43,7 +40,6 @@ sub TO_JSON {
     return \%output;
 }
 
-
 sub compute_bbox {
     return Geo::JSON::Utils::compute_bbox( shift->all_positions );
 }
@@ -56,17 +52,11 @@ sub all_positions {
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-Geo::JSON::Base - Base class for Geo::JSON objects
-
-=head1 VERSION
-
-version 0.006
+Geo::JSON::Base - Baseclass for Geo::JSON objects
 
 =head1 DESCRIPTION
 
@@ -104,15 +94,5 @@ in the object's geometry.
 Returns arrayref of all positions (each an arrayref of C<n> dimensions) in the
 object's geometry.
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
