@@ -1,8 +1,6 @@
 package Geo::JSON::CRS;
 
-our $VERSION = '0.006'; # VERSION
-
-# ABSTRACT: Co-ordinate Reference System object
+our $VERSION = '0.007';
 
 use Moo;
 with 'Geo::JSON::Role::ToJson';
@@ -22,23 +20,16 @@ has type => (
 
 has properties => ( is => 'ro', isa => HashRef, required => 1 );
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
 Geo::JSON::CRS - Co-ordinate Reference System object
 
-=head1 VERSION
-
-version 0.006
-
 =head1 SYNOPSIS
 
     use Geo::JSON::CRS;
@@ -97,15 +88,5 @@ string identifying the CRS.
 For objects of type 'link', 'href' and 'type' keys are required. Link types
 are not restricted, examples include "proj4", "ogcwkt", "esriwkt",
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
