@@ -1,8 +1,6 @@
 package Geo::JSON::Feature;
 
-our $VERSION = '0.006'; # VERSION
-
-# ABSTRACT: object representing a geojson Feature
+our $VERSION = '0.007';
 
 use Moo;
 extends 'Geo::JSON::Base';
@@ -29,23 +27,16 @@ sub all_positions {
     return shift->geometry->all_positions;
 }
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
 Geo::JSON::Feature - object representing a geojson Feature
 
-=head1 VERSION
-
-version 0.006
-
 =head1 SYNOPSIS
 
     use Geo::JSON::Feature;
@@ -92,15 +83,5 @@ L<Geo::JSON::MultiPolygon>
 
 See L<Geo::JSON> for more details.
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
