@@ -1,8 +1,6 @@
 package Geo::JSON::FeatureCollection;
 
-our $VERSION = '0.006'; # VERSION
-
-# ABSTRACT: object representing a geojson FeatureCollection
+our $VERSION = '0.007';
 
 use Moo;
 extends 'Geo::JSON::Base';
@@ -26,23 +24,16 @@ sub all_positions {
     return [ map { @{ $_->all_positions } } @{ $self->features } ];
 }
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
 Geo::JSON::FeatureCollection - object representing a geojson FeatureCollection
 
-=head1 VERSION
-
-version 0.006
-
 =head1 SYNOPSIS
 
     use Geo::JSON::FeatureCollection;
@@ -72,15 +63,5 @@ L<Geo::JSON::Feature>
 
 =back
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
