@@ -1,6 +1,6 @@
 package Geo::JSON::MultiPoint;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007';
 
 # ABSTRACT: object representing a geojson MultiPoint
 
@@ -12,27 +12,20 @@ use Geo::JSON::Types -types;
 
 has '+coordinates' => ( isa => Positions );
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-Geo::JSON::MultiPoint - object representing a geojson MultiPoint
-
-=head1 VERSION
-
-version 0.006
+Geo::JSON::MultiPoint
 
 =head1 SYNOPSIS
 
     use Geo::JSON::MultiPoint;
-    my $mpt = Geo::JSON::Point->new({
+    my $mpt = Geo::JSON::MultiPoint->new({
         coordinates => [ [ 51.50101, -0.14159 ],
                          [ 57.596278, -13.687306 ],
                        ],
@@ -46,15 +39,5 @@ positions.
 
 See L<Geo::JSON> for more details.
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
