@@ -1,6 +1,6 @@
 package Geo::JSON::MultiPolygon;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007';
 
 # ABSTRACT: object representing a geojson MultiPolygon
 
@@ -21,22 +21,15 @@ sub all_positions {
     ];
 }
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-Geo::JSON::MultiPolygon - object representing a geojson MultiPolygon
-
-=head1 VERSION
-
-version 0.006
+Geo::JSON::MultiPolygon
 
 =head1 SYNOPSIS
 
@@ -58,15 +51,5 @@ A GeoJSON object with a coordinates of an arrayref of polygon coordinates.
 
 See L<Geo::JSON> for more details.
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
