@@ -1,6 +1,6 @@
 package Geo::JSON::Point;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007';
 
 # ABSTRACT: object representing a geojson Point
 
@@ -20,22 +20,15 @@ before compute_bbox => sub {
 
 sub all_positions { [ shift->coordinates ] }
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-Geo::JSON::Point - object representing a geojson Point
-
-=head1 VERSION
-
-version 0.006
+Geo::JSON::Point
 
 =head1 SYNOPSIS
 
@@ -51,15 +44,5 @@ A GeoJSON object with a coordinates attribute of a single position.
 
 See L<Geo::JSON> for more details.
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
