@@ -1,6 +1,6 @@
 package Geo::JSON::Polygon;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007';
 
 # ABSTRACT: object representing a geojson Polygon
 
@@ -18,22 +18,15 @@ sub all_positions {
     return [ map { @{$_} } @{ $self->coordinates } ];
 }
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
-Geo::JSON::Polygon - object representing a geojson Polygon
-
-=head1 VERSION
-
-version 0.006
+Geo::JSON::Polygon
 
 =head1 SYNOPSIS
 
@@ -53,15 +46,5 @@ or holes.
 
 See L<Geo::JSON> for more details.
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
