@@ -1,8 +1,6 @@
 package Geo::JSON::Types;
 
-our $VERSION = '0.006'; # VERSION
-
-# ABSTRACT: Type::Tiny data types for Geo::JSON classes
+our $VERSION = '0.007';
 
 use strict;
 use warnings;
@@ -55,7 +53,6 @@ BEGIN {
 
     class_type CRS,      { class => 'Geo::JSON::CRS' };
     class_type Feature,  { class => 'Geo::JSON::Feature' };
-#    class_type Geometry, { class => 'Geo::JSON::Geometry' };
 
     coerce CRS, from HashRef, q{ 'Geo::JSON::CRS'->new($_) };
 
@@ -66,23 +63,16 @@ BEGIN {
     declare Features, as ArrayRef [Feature], coercion => 1;
 }
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
 Geo::JSON::Types - Type::Tiny data types for Geo::JSON classes
 
-=head1 VERSION
-
-version 0.006
-
 =head1 SYNOPSIS
 
     use Geo::JSON::Types -types;
@@ -156,15 +146,5 @@ Polygons
 
 =back
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
