@@ -1,8 +1,6 @@
 package Geo::JSON::Utils;
 
-our $VERSION = '0.006'; # VERSION
-
-# ABSTRACT: Util methods for Geo::JSON classes
+our $VERSION = '0.007';
 
 use strict;
 use warnings;
@@ -12,8 +10,7 @@ use base 'Exporter';
 
 our @EXPORT_OK = qw/ compare_positions compute_bbox /;
 
-
-# TODO make better - need to ensure floating points are the same
+# TODO improve - need to ensure floating points are the same
 sub compare_positions {
     my ( $pos1, $pos2 ) = @_;
 
@@ -32,7 +29,6 @@ sub compare_positions {
     return 1;
 }
 
-
 sub compute_bbox {
     my $positions = shift;    # arrayref of positions
 
@@ -57,23 +53,16 @@ sub compute_bbox {
     return [ @min, @max ];
 }
 
-
 1;
 
 __END__
 
-=pod
-
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
 Geo::JSON::Utils - Util methods for Geo::JSON classes
 
-=head1 VERSION
-
-version 0.006
-
 =head1 SYNOPSIS
 
     use Geo::JSON::Utils qw/ compare_positions compute_bbox /;
@@ -93,6 +82,9 @@ Util methods for L<Geo::JSON>
 Compare two points. Compares in up to three dimensions. Any further
 dimensions are ignored.
 
+=cut
+
+
 =head2 compute_bbox
 
     my $bbox = Geo::JSON::Utils::compute_bbox( \@positions );
@@ -103,25 +95,18 @@ values are in the order the axis they appear in the position geometry.
 
 Assumes all points will have same number of dimensions as the first.
 
+=cut
+
 =head1 TODO
 
 =over
 
 =item *
 
-Improve comparisons of floating point coordinates, look at stringification issues, etc.
+Improve comparisons of floating point coordinates, look at stringification
+issues, etc.
 
 =back
 
-=head1 AUTHOR
-
-Michael Jemmeson <mjemmeson@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Michael Jemmeson <mjemmeson@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
